@@ -161,7 +161,7 @@ bool AuroraeFactory::reset(unsigned long changed)
     if (changed & SettingFont){
         emit titleFontChanged();
     }
-    if (changed & SettingCompositing) {
+    if (changed == SettingCompositing) {
         return false;
     }
     const KConfig conf("auroraerc");
@@ -180,7 +180,7 @@ bool AuroraeFactory::reset(unsigned long changed)
         m_theme->setButtonSize((KDecorationDefines::BorderSize)themeGroup.readEntry<int>("ButtonSize", KDecorationDefines::BorderNormal));
     }
     emit configChanged();
-    return false; // need hard reset
+    return changed & (SettingDecoration | SettingButtons | SettingBorder); // need hard reset
 }
 
 bool AuroraeFactory::supports(Ability ability) const
@@ -407,7 +407,7 @@ KDecorationDefines::Position AuroraeClient::mousePosition(const QPoint &point) c
 {
     // based on the code from deKorator
     int pos = PositionCenter;
-    if (isShade()) {
+    if (isShade() || isMaximized()) {
         return Position(pos);
     }
 
@@ -415,9 +415,8 @@ KDecorationDefines::Position AuroraeClient::mousePosition(const QPoint &point) c
     borders(borderLeft, borderRight, borderTop, borderBottom);
     int paddingLeft, paddingTop, paddingRight, paddingBottom;
     padding(paddingLeft, paddingRight, paddingTop, paddingBottom);
-    const bool maximized = maximizeMode() == MaximizeFull && !options()->moveResizeMaximizedWindows();
     int titleEdgeLeft, titleEdgeRight, titleEdgeTop, titleEdgeBottom;
-    AuroraeFactory::instance()->theme()->titleEdges(titleEdgeLeft, titleEdgeTop, titleEdgeRight, titleEdgeBottom, maximized);
+    AuroraeFactory::instance()->theme()->titleEdges(titleEdgeLeft, titleEdgeTop, titleEdgeRight, titleEdgeBottom, false);
     switch (AuroraeFactory::instance()->theme()->decorationPosition()) {
     case DecorationTop:
         borderTop = titleEdgeTop;
