@@ -60,6 +60,7 @@
 SearchLaunch::SearchLaunch(QObject *parent, const QVariantList &args)
     : Containment(parent, args),
       m_runnerModel(0),
+      m_serviceModel(0),
       m_backButton(0),
       m_queryCounter(0),
       m_maxColumnWidth(0),
@@ -275,6 +276,10 @@ void SearchLaunch::configChanged()
         }
     }
 
+    if (m_serviceModel) {
+        m_serviceModel->setPath("/");
+    }
+    restoreStrip();
     m_stripUninitialized = false;
 }
 
@@ -569,7 +574,7 @@ void SearchLaunch::restoreStrip()
 {
     KConfigGroup cg = config();
     m_stripWidget->restore(cg);
-    reset();
+    //reset();
 }
 
 void SearchLaunch::updateConfigurationMode(bool config)
